==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/pl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Prywatność",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Centrum prywatności pokazuje, gdzie są przechowywane Twoje dane i kto może uzyskać do nich dostęp, ponieważ udostępniłeś je lub jesteś administratorem.",
    "Add external admin" : "Dodaj zewnętrznego administratora",
    "Your files are not protected by encryption." : "Twoje pliki nie są chronione przez szyfrowanie.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Ten serwer jest chroniony za pomocą full-disk-encryption.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}. Ponadto ten serwer jest chroniony za pomocą full-disk-encryption.",
    "This server is using full-disk-encryption." : "Ten serwer używa full-disk-encryption.",
    "Your data is located in: " : "Twoje dane znajdują się w: ",
    "The admin hasn't selected the location of the server yet." : "Administrator nie wybrał jeszcze lokalizacji serwera.",
    "Please select a country" : "Wybierz kraj",
    "You don't have any shares with individual users." : "Nie masz żadnych udostępnień dla poszczególnych użytkowników.",
    "Somaliland" : "Somalia",
    "United Arab Emirates" : "Zjednoczone Emiraty Arabskie",
    "Afghanistan" : "Afganistan",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentyna",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbejdżan",
    "Bosnia and Herzegowina" : "Bośnia i Hercegowina",
    "Bangladesh" : "Bangladesz",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bułgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Boliwia",
    "Brazil" : "Brazylia",
    "Bahamas" : "Bahamy",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Białoruś",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Demokratyczna Republika Konga",
    "Central African Republic" : "Republika Środkowoafrykańska",
    "Congo" : "Kongo",
    "Switzerland" : "Szwajcaria",
    "Cote d'Ivoire" : "Wybrzeże Kości Słoniowej",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Chiny",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Kostaryka",
    "Cuba" : "Kuba",
    "Cyprus" : "Cypr",
    "Czech" : "Czechy",
    "Germany" : "Niemcy",
    "Djibouti" : "Dżibuti",
    "Denmark" : "Dania",
    "Dominican Republic" : "Republika Dominikany",
    "Algeria" : "Algieria",
    "Ecuador" : "Ekwador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipt",
    "West Sahara" : "Sahara Zachodnia",
    "Eritrea" : "Erytrea",
    "Spain" : "Hiszpania",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fidżi",
    "Falkland Islands" : "Falklandy",
    "France" : "Francja",
    "Gabon" : "Gabon",
    "United Kingdom" : "Zjednoczone Królestwo",
    "Georgia" : "Gruzja",
    "Ghana" : "Ghana",
    "Greenland" : "Grenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Gwinea",
    "Equatorial Guinea" : "Gwinea Równikowa",
    "Greece" : "Grecja",
    "Guatemala" : "Gwatemala",
    "Guinea-Bissau" : "Gwinea Bissau",
    "Guyana" : "Gujana",
    "Honduras" : "Honduras",
    "Croatia" : "Chorwacja",
    "Haiti" : "Haiti",
    "Hungary" : "Węgry",
    "Indonesia" : "Indonezja",
    "Ireland" : "Irlandia",
    "Israel" : "Izrael",
    "India" : "Indie",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islandia",
    "Italy" : "Włochy",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordania",
    "Japan" : "Japonia",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodża",
    "North Korea" : "Korea Północna",
    "South Korea" : "Korea Południowa",
    "Kuwait" : "Kuwejt",
    "Kazakhstan" : "Kazachstan",
    "Laos" : "Laos",
    "Lebanon" : "Liban",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litwa",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Łotwa",
    "Libya" : "Libia",
    "Morocco" : "Maroko",
    "Moldova" : "Mołdawia",
    "Montenegro" : "Czarnogóra",
    "Madagascar" : "Madagaskar",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Mjanma",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauretania",
    "Malawi" : "Malawi",
    "Mexico" : "Meksyk",
    "Malaysia" : "Malezja",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nowa Kaledonia",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Holandia",
    "Norway" : "Norwegia",
    "Nepal" : "Nepal",
    "New Zealand" : "Nowa Zelandia",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua Nowa Gwinea",
    "Philippines" : "Filipiny",
    "Pakistan" : "Pakistan",
    "Poland" : "Polska",
    "Puerto Rico" : "Portoryko",
    "Portugal" : "Portugalia",
    "Paraguay" : "Paragwaj",
    "Qatar" : "Katar",
    "Romania" : "Rumunia",
    "Serbia" : "Serbia",
    "Russia" : "Rosja",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabia Saudyjska",
    "Solomon Islands" : "Wyspy Salomona",
    "Sudan" : "Sudan",
    "Sweden" : "Szwecja",
    "Singapore" : "Singapur",
    "Slovenia" : "Słowenia",
    "Slovakia" : "Słowacja",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Południowy Sudan",
    "El Salvador" : "Salwador",
    "Syria" : "Syria",
    "Swaziland" : "Eswatini",
    "Chad" : "Czad",
    "Fr. S. Antarctic Lands" : "Ks. Ziemie S. Antarktyczne",
    "Togo" : "Togo",
    "Thailand" : "Tajlandia",
    "Tajikistan" : "Tadżykistan",
    "Timor-Leste" : "Timor Wschodni",
    "Turkmenistan" : "Turkmenia",
    "Tunisia" : "Tunezja",
    "Turkey" : "Turcja",
    "Trinidad and Tobago" : "Trynidad i Tobago",
    "Taiwan" : "Tajwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States" : "Stany Zjednoczone",
    "Uruguay" : "Urugwaj",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Wenezuela",
    "Vietnam" : "Wietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Jemen",
    "South Africa" : "Afryka Południowa",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Twoje konto Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Twoje dane reprezentują Ciebie, które mogą być w łatwy sposób nadużywane. W Nextcloud wierzymy, że masz prawo decydować o tym, co dzieje się z Twoimi danymi. Nextcloud chroni Twoje prawa zgodnie z definicją w User Data Manifesto!",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Określenie podstawowych praw do kontroli własnych danych w dobie internetu",
    "Control" : "Kontrola",
    "over user data access" : "dostęp do danych użytkownika",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Dane jawnie i dobrowolnie przesłane przez użytkownika powinny być pod ostateczną kontrolą użytkownika. Użytkownicy powinni mieć możliwość decydowania, komu przyznać bezpośredni dostęp do swoich danych oraz jakie pozwolenia powinny zostać przyznane.",
    "Knowledge" : "Wiedza",
    "of how the data is stored" : "sposób przechowywania danych",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kiedy dane są przesyłane do określonego usługodawcy, użytkownicy powinni być informowani o tym, gdzie dany dostawca usług przechowuje dane, jak długo, w jakiej jurysdykcji działa dany usługodawca, i które przepisy mają zastosowanie.",
    "Freedom" : "Dowolność",
    "to choose a platform" : "wybór platformy",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Użytkownicy powinni mieć zawsze możliwość wyodrębnienia swoich danych z usługi w dowolnym czasie, nie mając możliwości zablokowania dostawcy. Aby to zagwarantować, niezbędne są otwarte standardy formatów i protokołów.",
    "Learn more ↗" : "Dowiedz się więcej ↗",
    "Where is your data?" : "Gdzie są Twoje dane?",
    "Who has access to your data?" : "Kto ma dostęp do Twoich danych?",
    "Administrators" : "Administratorzy",
    "People you shared with" : "Osoby, którym udostępniasz",
    "Privacy policy" : "Polityka prywatności",
    "Read the privacy policy." : "Przeczytaj politykę prywatności.",
    "Encryption" : "Szyfrowanie"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-23.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/pl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Prywatność",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Centrum prywatności pokazuje, gdzie są przechowywane Twoje dane i kto może uzyskać do nich dostęp, ponieważ udostępniłeś je lub jesteś administratorem.",
    "Remove external admin" : "Usuń zewnętrznego administratora",
    "Add external admin" : "Dodaj zewnętrznego administratora",
    "Name of external admin" : "Nazwa zewnętrznego administratora",
    "This server is using full-disk-encryption." : "Ten serwer używa full-disk-encryption.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "Twój magazyn główny jest zaszyfrowany przy użyciu {linkopen}server-side-encryption ↗{linkclose} z kluczem głównym.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Twoje pliki na magazynach zewnętrznych mogą być zaszyfrowane przy użyciu {linkopen}server-side-encryption ↗{linkclose} z kluczem głównym opartym na ich konfiguracji.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "Twój magazyn główny jest zaszyfrowany przy użyciu {linkopen}server-side-encryption ↗{linkclose} z indywidualnym kluczem użytkownika.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Twoje pliki na magazynach zewnętrznych mogą być zaszyfrowane przy użyciu {linkopen}server-side-encryption ↗{linkclose} z indywidualnym kluczem opartym na ich konfiguracji.",
    "Additionally, this server is protected with full-disk-encryption." : "Dodatkowo ten serwer jest chroniony szyfrowaniem full-disk-encryption.",
    "This server is protected with full-disk-encryption." : "Ten serwer jest chroniony za pomocą full-disk-encryption.",
    "Your files are not protected by encryption." : "Twoje pliki nie są chronione przez szyfrowanie.",
    "Your data is located in:" : "Twoje dane znajdują się w:",
    "The admin has not selected the location of the server yet." : "Administrator nie wybrał jeszcze lokalizacji serwera.",
    "Change data location" : "Zmień dane lokalizacji",
    "Please select a region" : "Wybierz region",
    "You don't have any shares with individual users." : "Nie masz żadnych udostępnień dla poszczególnych użytkowników.",
    "Somaliland" : "Somalia",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Zjednoczone Emiraty Arabskie",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua i Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktyda",
    "Argentina" : "Argentyna",
    "American Samoa" : "Samoa Amerykańskie",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Wyspy Alandzkie",
    "Azerbaijan" : "Azerbejdżan",
    "Bosnia and Herzegovina" : "Bośnia i Hercegowina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesz",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bułgaria",
    "Bahrain" : "Bahrajn",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermudy",
    "Brunei" : "Brunei",
    "Bolivia" : "Boliwia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius i Saba (Holandia Karaibska)",
    "Brazil" : "Brazylia",
    "Bahamas" : "Bahamy",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Wyspa Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Białoruś",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Wyspy Kokosowe (Keelinga)",
    "Democratic Republic of the Congo" : "Demokratyczna Republika Konga",
    "Central African Republic" : "Republika Środkowoafrykańska",
    "Congo" : "Kongo",
    "Switzerland" : "Szwajcaria",
    "Cote d'Ivoire" : "Wybrzeże Kości Słoniowej",
    "Cook Islands" : "Wyspy Cooka",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Chiny",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Kostaryka",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Wyspa Bożego Narodzenia",
    "Cyprus" : "Cypr",
    "Czech" : "Czechy",
    "Germany" : "Niemcy",
    "Djibouti" : "Dżibuti",
    "Denmark" : "Dania",
    "Dominican Republic" : "Republika Dominikany",
    "Algeria" : "Algieria",
    "Ecuador" : "Ekwador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipt",
    "West Sahara" : "Sahara Zachodnia",
    "Eritrea" : "Erytrea",
    "Spain" : "Hiszpania",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fidżi",
    "Falkland Islands" : "Falklandy",
    "Micronesia" : "Mikronezja",
    "Faroe Islands" : "Wyspy Owcze",
    "France" : "Francja",
    "Gabon" : "Gabon",
    "United Kingdom" : "Zjednoczone Królestwo",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzja",
    "French Guiana" : "Gujana Francuska",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Gwinea",
    "Guadeloupe" : "Gwadelupa",
    "Equatorial Guinea" : "Gwinea Równikowa",
    "Greece" : "Grecja",
    "South Georgia and the South Sandwich Islands" : "Georgia Południowa i Sandwich Południowy",
    "Guatemala" : "Gwatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Gwinea Bissau",
    "Guyana" : "Gujana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Wyspy Heard i McDonalda",
    "Croatia" : "Chorwacja",
    "Haiti" : "Haiti",
    "Hungary" : "Węgry",
    "Indonesia" : "Indonezja",
    "Ireland" : "Irlandia",
    "Israel" : "Izrael",
    "Isle of Man" : "Wyspa Man",
    "India" : "Indie",
    "British Indian Ocean Territory" : "Brytyjskie Terytorium Oceanu Indyjskiego",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islandia",
    "Italy" : "Włochy",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordania",
    "Japan" : "Japonia",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodża",
    "Kiribati" : "Kiribati",
    "Comores" : "Komory",
    "Saint Kitts and Nevis" : "Saint Kitts i Nevis",
    "North Korea" : "Korea Północna",
    "South Korea" : "Korea Południowa",
    "Kuwait" : "Kuwejt",
    "Cayman Islands" : "Kajmany",
    "Kazakhstan" : "Kazachstan",
    "Laos" : "Laos",
    "Lebanon" : "Liban",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litwa",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Łotwa",
    "Libya" : "Libia",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova" : "Mołdawia",
    "Montenegro" : "Czarnogóra",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Wyspy Marshalla",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Mjanma",
    "Mongolia" : "Mongolia",
    "Macao" : "Makau",
    "Northern Mariana Islands" : "Mariany Północne",
    "Mauritania" : "Mauretania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Malediwy",
    "Malawi" : "Malawi",
    "Mexico" : "Meksyk",
    "Malaysia" : "Malezja",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nowa Kaledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Wyspa Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Holandia",
    "Norway" : "Norwegia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nowa Zelandia",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Polinezja Francuska",
    "Papua New Guinea" : "Papua Nowa Gwinea",
    "Philippines" : "Filipiny",
    "Pakistan" : "Pakistan",
    "Poland" : "Polska",
    "Saint Pierre and Miquelon" : "Saint Pierre i Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Portoryko",
    "Palestine" : "Palestyna",
    "Portugal" : "Portugalia",
    "Palau" : "Palau",
    "Paraguay" : "Paragwaj",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rumunia",
    "Serbia" : "Serbia",
    "Russia" : "Rosja",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabia Saudyjska",
    "Solomon Islands" : "Wyspy Salomona",
    "Seychelles" : "Seszele",
    "Sudan" : "Sudan",
    "Sweden" : "Szwecja",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Wyspa Świętej Heleny, Wyspa Wniebowstąpienia i Tristan da Cunha",
    "Slovenia" : "Słowenia",
    "Svalbard and Jan Mayen" : "Svalbard i Jan Mayen",
    "Slovakia" : "Słowacja",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Południowy Sudan",
    "Sao Tome and Principe" : "Wyspy Świętego Tomasza i Książęca",
    "El Salvador" : "Salwador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Syria",
    "Swaziland" : "Eswatini",
    "Turks and Caicos Islands" : "Wyspy Turks i Caicos",
    "Chad" : "Czad",
    "Fr. S. Antarctic Lands" : "Ks. Ziemie S. Antarktyczne",
    "Togo" : "Togo",
    "Thailand" : "Tajlandia",
    "Tajikistan" : "Tadżykistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Wschodni",
    "Turkmenistan" : "Turkmenia",
    "Tunisia" : "Tunezja",
    "Tonga" : "Tonga",
    "Turkey" : "Turcja",
    "Trinidad and Tobago" : "Trynidad i Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Tajwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Dalekie Wyspy Mniejsze Stanów Zjednoczonych",
    "United States" : "Stany Zjednoczone",
    "Uruguay" : "Urugwaj",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Stolica Apostolska",
    "Saint Vincent and the Grenadines" : "Saint Vincent i Grenadyny",
    "Venezuela" : "Wenezuela",
    "Virgin Islands (British)" : "Wyspy Dziewicze (Brytyjskie)",
    "Virgin Islands (U.S.)" : "Wyspy Dziewicze (Stany Zjednoczone)",
    "Vietnam" : "Wietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis i Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Majotta",
    "South Africa" : "Afryka Południowa",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your %s account" : "Twoje konto %s",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Twoje dane reprezentują Ciebie, które mogą być w łatwy sposób nadużywane. W Nextcloud wierzymy, że masz prawo decydować o tym, co dzieje się z Twoimi danymi. Nextcloud chroni Twoje prawa zgodnie z definicją w User Data Manifesto!",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Określenie podstawowych praw do kontroli własnych danych w dobie internetu",
    "Control" : "Kontrola",
    "over user data access" : "dostęp do danych użytkownika",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Dane jawnie i dobrowolnie przesłane przez użytkownika powinny być pod ostateczną kontrolą użytkownika. Użytkownicy powinni mieć możliwość decydowania, komu przyznać bezpośredni dostęp do swoich danych oraz jakie pozwolenia powinny zostać przyznane.",
    "Knowledge" : "Wiedza",
    "of how the data is stored" : "sposób przechowywania danych",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kiedy dane są przesyłane do określonego usługodawcy, użytkownicy powinni być informowani o tym, gdzie dany dostawca usług przechowuje dane, jak długo, w jakiej jurysdykcji działa dany usługodawca, i które przepisy mają zastosowanie.",
    "Freedom" : "Dowolność",
    "to choose a platform" : "wybór platformy",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Użytkownicy powinni mieć zawsze możliwość wyodrębnienia swoich danych z usługi w dowolnym czasie, bez możliwości zablokowania przez dostawcę. Aby to zagwarantować, niezbędne są otwarte standardy formatów i protokołów.",
    "Learn more ↗" : "Dowiedz się więcej ↗",
    "Where is your data?" : "Gdzie są Twoje dane?",
    "Who has access to your data?" : "Kto ma dostęp do Twoich danych?",
    "Administrators" : "Administratorzy",
    "People you shared with" : "Osoby, którym udostępniasz",
    "Privacy policy" : "Polityka prywatności",
    "Read the privacy policy." : "Przeczytaj politykę prywatności.",
    "Encryption" : "Szyfrowanie",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}. Ponadto ten serwer jest chroniony za pomocą full-disk-encryption.",
    "Your data is located in: " : "Twoje dane znajdują się w: ",
    "The admin hasn't selected the location of the server yet." : "Administrator nie wybrał jeszcze lokalizacji serwera."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
